@@ -37,8 +37,22 @@
 #include <QApt/Backend>
 #include <QApt/Package>
 
-using namespace QApt;
+#include <polkit-qt5-1/PolkitQt1/Authority>
 
+using namespace QApt;
+using namespace PolkitQt1;
+
+bool checkAuthorization(const QString &actionId, qint64 applicationPid)
+{
+    Authority::Result result;
+    result = Authority::instance()->checkAuthorizationSync(actionId, UnixProcessSubject(applicationPid), /// 第一个参数是需要验证的action，和规则文件写的保持一致
+                                                           Authority::AllowUserInteraction);
+    if (result == Authority::Yes) {
+        return true;
+    } else {
+        return false;
+    }
+}
 /**
  * @brief isDpkgRunning 判断当前dpkg 是否在运行
  * @return
@@ -51,10 +65,7 @@ DebListModel::DebListModel(QObject *parent)
     , m_packagesManager(new PackagesManager(this))
 {
     // 配置包安装的进程
-    m_procInstallConfig = new QProcess;
-    m_procInstallConfig->setProcessChannelMode(QProcess::MergedChannels);               //获取子进程所有的输出数据
-    m_procInstallConfig->setReadChannel(QProcess::StandardOutput);                      //QProcess 当前从标准输出中读取所有的数据
-
+    m_procInstallConfig = new Konsole::Pty;
     configWindow = new AptConfigMessage;
 
     // 链接信号与槽
@@ -175,7 +186,7 @@ void DebListModel::initInstallConnections()
     connect(m_procInstallConfig, static_cast<void (QProcess::*)(int)>(&QProcess::finished), this, &DebListModel::slotConfigInstallFinish);
 
     // 配置安装的过程数据
-    connect(m_procInstallConfig, &QProcess::readyReadStandardOutput, this, &DebListModel::slotConfigReadOutput);
+    connect(m_procInstallConfig, &Konsole::Pty::receivedData, this, &DebListModel::slotConfigReadOutput);
 
     // 向安装进程中写入配置信息（一般是配置的序号）
     connect(configWindow, &AptConfigMessage::AptConfigInputStr, this, &DebListModel::slotConfigInputWrite);
@@ -280,7 +291,7 @@ QVariant DebListModel::data(const QModelIndex &index, int role) const
 {
     const int currentRow = index.row();
     // 判断当前下标是否越界
-    if (currentRow >= m_packagesManager->m_preparedPackages.size() ) {
+    if (currentRow >= m_packagesManager->m_preparedPackages.size()) {
         return QVariant();
     }
     //当前给出的路径文件已不可访问.直接删除该文件
@@ -386,18 +397,17 @@ void DebListModel::slotUninstallPackage(const int index)
     const QStringList rdepends = m_packagesManager->packageReverseDependsList(debFile.packageName(), debFile.architecture()); //检查是否有应用依赖到该包
     Backend *backend = m_packagesManager->m_backendFuture.result();
     for (const auto &r : rdepends) {                                        // 卸载所有依赖该包的应用（二者的依赖关系为depends）
-        if (backend->package(r)){
+        if (backend->package(r)) {
             // 更换卸载包的方式，remove卸载不卸载完全会在影响下次安装的依赖判断。
             backend->package(r)->setPurge();
-        }
-        else
+        } else
             qWarning() << "DebListModel:" << "reverse depend" << r << "error ,please check it!";
     }
     //卸载当前包 更换卸载包的方式，remove卸载不卸载完全会在影响下次安装的依赖判断。
     QApt::Package *uninstalledPackage = backend->package(debFile.packageName() + ':' + debFile.architecture());
 
     //未通过当前包的包名以及架构名称获取package对象，刷新操作状态为卸载失败
-    if(!uninstalledPackage){
+    if (!uninstalledPackage) {
         refreshOperatingPackageStatus(Failed);
         return;
     }
@@ -431,8 +441,8 @@ void DebListModel::slotUninstallPackage(const int index)
 
 void DebListModel::removePackage(const int idx)
 {
-    if(WorkerPrepare != m_workerStatus){
-        qWarning()<<"installer status error";
+    if (WorkerPrepare != m_workerStatus) {
+        qWarning() << "installer status error";
     }
     // 去除操作状态 中的index
     int packageOperateStatusCount = m_packageOperateStatus.size() - 1;
@@ -446,8 +456,8 @@ void DebListModel::removePackage(const int idx)
 
 void DebListModel::slotAppendPackage(QStringList package)
 {
-    if(WorkerPrepare != m_workerStatus){
-        qWarning()<<"installer status error";
+    if (WorkerPrepare != m_workerStatus) {
+        qWarning() << "installer status error";
     }
     m_packagesManager->appendPackage(package);      //添加包，并返回添加结果
 }
@@ -518,11 +528,11 @@ void DebListModel::bumpInstallIndex()
 
 void DebListModel::slotTransactionErrorOccurred()
 {
-    if(WorkerProcessing != m_workerStatus){
-        qWarning()<<"installer status error";
+    if (WorkerProcessing != m_workerStatus) {
+        qWarning() << "installer status error";
     }
     Transaction *transaction = qobject_cast<Transaction *>(sender());
-    if(!transaction)
+    if (!transaction)
         return;
     //失败时刷新操作状态为failed,并记录失败原因
     refreshOperatingPackageStatus(Failed);
@@ -542,7 +552,7 @@ void DebListModel::slotTransactionErrorOccurred()
     if (transaction->isCancellable()) transaction->cancel();
 
     //特殊处理授权错误
-    if (AuthError == errorCode ) {
+    if (AuthError == errorCode) {
         transaction->deleteLater();                                                       //删除 trans指针
         QTimer::singleShot(100 * 1, this, &DebListModel::checkBoxStatus);           //检查授权弹窗的状态 如果弹窗仍然在只是超时，则底层窗口按钮不可用
         qWarning() << "DebListModel:" << "Authorization error";
@@ -572,11 +582,12 @@ QString DebListModel::packageFailedReason(const int idx) const
 {
     const auto dependStatus = m_packagesManager->getPackageDependsStatus(idx);                         //获取包的依赖状态
     const auto md5 = m_packagesManager->getPackageMd5(idx);                                 //获取包的md5值
-    if (m_packagesManager->isArchError(idx)) return tr("Unmatched package architecture");   //判断是否架构冲突
-    if(dependStatus.isProhibit())
+    if (m_packagesManager->isArchError(idx))
+        return tr("Unmatched package architecture");   //判断是否架构冲突
+    if (dependStatus.isProhibit())
         return tr("The administrator has set policies to prevent installation of this package");
     if (dependStatus.isBreak() || dependStatus.isAuthCancel()) {                                            //依赖状态错误
-        if (!dependStatus.package.isEmpty()) {
+        if (!dependStatus.package.isEmpty() || !m_brokenDepend.isEmpty()) {
             if (m_packagesManager->m_errorIndex.contains(md5))     //修改wine依赖的标记方式
                 return tr("Failed to install %1").arg(m_brokenDepend); //wine依赖安装失败
             return tr("Broken dependencies: %1").arg(dependStatus.package);                         //依赖不满足
@@ -585,11 +596,10 @@ QString DebListModel::packageFailedReason(const int idx) const
         const auto conflictStatus = m_packagesManager->packageConflictStat(idx);                  //获取冲突情况
         if (!conflictStatus.is_ok())
             return tr("Broken dependencies: %1").arg(conflictStatus.unwrap()); //依赖冲突
-        qInfo() << "================" << dependStatus.package;
     }
 
-    if(m_packageOperateStatus.contains(md5) && m_packageOperateStatus[md5] == Failed)
-        qWarning()<<"package operate status failed";
+    if (m_packageOperateStatus.contains(md5) && m_packageOperateStatus[md5] == Failed)
+        qWarning() << "package operate status failed";
     //判断当前这个包是否错误
     if (!m_packageFailCode.contains(md5))
         qWarning() << "DebListModel:" << "failed to get reason" << m_packageFailCode.size() << idx;
@@ -605,8 +615,8 @@ void DebListModel::slotTransactionFinished()
     }
     // 获取trans指针
     Transaction *transaction = qobject_cast<Transaction *>(sender());
-    if(!transaction)
-       return;
+    if (!transaction)
+        return;
     // prevent next signal
     disconnect(transaction, &Transaction::finished, this, &DebListModel::slotTransactionFinished);  //不再接收trans结束的信号
 
@@ -654,8 +664,8 @@ void DebListModel::slotDependsInstallTransactionFinished()//依赖安装关系
         qWarning() << "installer status error";
     }
     Transaction *transaction = qobject_cast<Transaction *>(sender());
-    if(!transaction)
-       return;
+    if (!transaction)
+        return;
 
     const auto transExitStatus = transaction->exitStatus();
 
@@ -682,10 +692,7 @@ void DebListModel::slotDependsInstallTransactionFinished()//依赖安装关系
     if (transExitStatus) {
         bumpInstallIndex();                                                     //依赖安装失败，直接安装下一个包
     } else {
-        //检查当前应用是否在黑名单中
-        //非开发者模式且数字签名验证失败
-        if (checkBlackListApplication() || !checkDigitalSignature())
-            return;
+        // 安装依赖前已对此包进行黑名单及验签校验，无需二次验证
         installNextDeb();                                                       //依赖安装成功，开始安装这个包
     }
 }
@@ -939,28 +946,25 @@ void DebListModel::showDevelopDigitalErrWindow(ErrorCode code)
     cancelBtn->setFocusPolicy(Qt::TabFocus);
     cancelBtn->setFocus();
 
-    bool continueBtnClicked = false;
-
     // 点击弹出窗口的关闭图标按钮
-    connect(Ddialog, &DDialog::aboutToClose, this, [=] {
+    connect(Ddialog, &DDialog::aboutToClose, this, [ = ] {
         //刷新当前包的操作状态，失败原因为数字签名校验失败
         digitalVerifyFailed(code);
     });
     connect(Ddialog, &DDialog::aboutToClose, Ddialog, &DDialog::deleteLater);
 
     //点击弹出窗口的确定按钮
-    connect(cancelBtn, &DPushButton::clicked, this, [=] {
+    connect(cancelBtn, &DPushButton::clicked, this, [ = ] {
         digitalVerifyFailed(code);
     });
     connect(cancelBtn, &DPushButton::clicked, Ddialog, &DDialog::deleteLater);
 
     QPushButton *continueBtn = qobject_cast<QPushButton *>(Ddialog->getButton(1));
     connect(continueBtn, &DPushButton::clicked, this, [&] {
-        continueBtnClicked = true;
         installNextDeb();
     }); //点击继续，进入安装流程
     connect(continueBtn, &DPushButton::clicked, Ddialog, &DDialog::deleteLater);
-    connect(Ddialog, &Dialog::signalClosed, this, [=] { digitalVerifyFailed(code); });
+    connect(Ddialog, &Dialog::signalClosed, this, [ = ] { digitalVerifyFailed(code); });
     connect(Ddialog, &Dialog::signalClosed, Ddialog, &DDialog::deleteLater);
 }
 
@@ -995,14 +999,17 @@ void DebListModel::checkSystemVersion()
 {
     // add for judge OS Version
     // 修改获取系统版本的方式 此前为  DSysInfo::deepinType()
+
+#if (DTK_VERSION >= DTK_VERSION_CHECK(5, 2, 2, 2))
     switch (Dtk::Core::DSysInfo::uosEditionType()) {            //获取系统的类型
-#if(DTK_VERSION > DTK_VERSION_CHECK(5,4,10,0))
+#if (DTK_VERSION > DTK_VERSION_CHECK(5, 4, 10, 0))
     case Dtk::Core::DSysInfo::UosEducation:                     //教育版
 #endif
     case Dtk::Core::DSysInfo::UosProfessional: //专业版
     case Dtk::Core::DSysInfo::UosHome: {                     //个人版
-        QDBusInterface *dbusInterFace = new QDBusInterface("com.deepin.deepinid", "/com/deepin/deepinid", "com.deepin.deepinid");
-        bool deviceMode = dbusInterFace->property("DeviceUnlocked").toBool();                            // 判断当前是否处于开发者模式
+        QDBusInterface *dbusInterFace = new QDBusInterface("com.deepin.sync.Helper", "/com/deepin/sync/Helper",
+                                                           "com.deepin.sync.Helper", QDBusConnection::systemBus());
+        bool deviceMode = dbusInterFace->property("DeveloperMode").toBool();                            // 判断当前是否处于开发者模式
         qInfo() << "DebListModel:" << "system editon:" << Dtk::Core::DSysInfo::uosEditionName() << "develop mode:" << deviceMode;
         m_isDevelopMode = deviceMode;
         delete dbusInterFace;
@@ -1016,6 +1023,31 @@ void DebListModel::checkSystemVersion()
         m_isDevelopMode =  true;
         break;
     }
+#else
+    switch (Dtk::Core::DSysInfo::deepinType()) {
+    case Dtk::Core::DSysInfo::DeepinDesktop:
+        m_isDevelopMode = true;
+        break;
+    case Dtk::Core::DSysInfo::DeepinPersonal:
+    case Dtk::Core::DSysInfo::DeepinProfessional:
+        QDBusInterface *dbusInterFace = new QDBusInterface("com.deepin.deepinid", "/com/deepin/deepinid", "com.deepin.deepinid");
+        bool deviceMode = dbusInterFace->property("DeviceUnlocked").toBool();                            // 判断当前是否处于开发者模式
+        qInfo() << "DebListModel:" << "system editon:" << Dtk::Core::DSysInfo::uosEditionName() << "develop mode:" << deviceMode;
+        m_isDevelopMode = deviceMode;
+        delete dbusInterFace;
+        break;
+    case Dtk::Core::DSysInfo::isCommunityEdition():
+    case Dtk::Core::DSysInfo::DeepinServer:
+        m_isDevelopMode = true;
+        break;
+    default:
+        m_isDevelopMode = true;
+        break;
+    }
+
+#endif
+
+
 }
 
 bool DebListModel::checkDigitalSignature()
@@ -1071,14 +1103,31 @@ bool DebListModel::checkDigitalSignature()
 
 void DebListModel::installNextDeb()
 {
-        QString sPackageName = m_packagesManager->m_preparedPackages[m_operatingIndex];
-        QStringList strFilePath;
-        if (checkTemplate(sPackageName)) {                      //检查当前包是否需要配置
-            rmdir();                                            //删除临时路径
-            m_procInstallConfig->start("pkexec", QStringList() << "deepin-deb-installer-dependsInstall" << "InstallConfig" << sPackageName);
+    QString sPackageName = m_packagesManager->m_preparedPackages[m_operatingIndex];
+    QStringList strFilePath;
+    if (checkTemplate(sPackageName)) {                      //检查当前包是否需要配置
+        rmdir();                                            //删除临时路径
+//        m_procInstallConfig->start("pkexec", QStringList() << "pkexec" << "deepin-deb-installer-dependsInstall" << "InstallConfig" << sPackageName, {}, 0, false);
+        // bug 121345配置授权弹窗文案需修改与需求一致
+        bool isAuth = checkAuthorization("com.deepin.pkexec.deepin-deb-installer-dependsInstall", QCoreApplication::applicationPid());
+        if (isAuth) {
+            m_procInstallConfig->start("sudo", {"sudo", "-S", "dpkg", "-i", sPackageName}, {}, 0, false);
         } else {
-            installDebs();                                      //普通安装
+            // 取消授权框
+            emit signalAppendOutputInfo("Error executing command as another user: Request dismissed");                                 //输出安装错误的原因
+            m_workerStatus = WorkerFinished;                            //刷新包安装器的工作状态
+
+            refreshOperatingPackageStatus(Failed);                      //刷新当前包的操作状态
+
+            // 修改map存储的数据格式，将错误原因与错误代码与包绑定，而非与下标绑定
+            m_packageOperateStatus[m_operatingPackageMd5] = Failed;
+            m_packageFailCode.insert(m_operatingPackageMd5, 0);       //保存失败原因
+            m_packageFailReason.insert(m_operatingPackageMd5, "");
+            bumpInstallIndex();
         }
+    } else {
+        installDebs();                                      //普通安装
+    }
 }
 
 void DebListModel::rmdir()
@@ -1087,7 +1136,7 @@ void DebListModel::rmdir()
     if (filePath.exists()) {
         if (!filePath.removeRecursively()) {
             qWarning() << "DebListModel:" << "remove temporary path failed";
-        } 
+        }
     }
 }
 
@@ -1167,7 +1216,7 @@ void DebListModel::slotUninstallFinished()
         m_packageOperateStatus[m_operatingPackageMd5] = Success;
     }
     emit signalWorkerFinished();                                          //发送结束信号（只有单包卸载）卸载结束就是整个流程的结束
-    trans->deleteLater();                                 
+    trans->deleteLater();
 }
 
 void DebListModel::slotSetCurrentIndex(const QModelIndex &modelIndex)
@@ -1255,6 +1304,8 @@ void DebListModel::slotConfigInstallFinish(int installResult)
     if (0 == installResult) {        //安装成功
         if (m_packagesManager->m_packageMd5DependsStatus[m_packagesManager->m_packageMd5[m_operatingIndex]].status == DependsOk) {
             refreshOperatingPackageStatus(Success);                 //刷新安装状态
+            m_procInstallConfig->terminate();                               //结束配置
+            m_procInstallConfig->close();
         }
         bumpInstallIndex();                                         //开始安装下一个
     } else {
@@ -1274,13 +1325,13 @@ void DebListModel::slotConfigInstallFinish(int installResult)
     }
     configWindow->hide();                        //隐藏配置窗口
     configWindow->clearTexts();                  //清楚配置信息
-    m_procInstallConfig->terminate();                               //结束配置
-    m_procInstallConfig->close();
+//    m_procInstallConfig->terminate();                               //结束配置
+//    m_procInstallConfig->close();
 }
 
-void DebListModel::slotConfigReadOutput()
+void DebListModel::slotConfigReadOutput(const char *buffer, int length, bool isCommandExec)
 {
-    QString tmp = m_procInstallConfig->readAllStandardOutput().data();                  //获取配置读取到的信息
+    QString tmp = QByteArray(buffer, length);                  //获取配置读取到的信息
 
     //检查命令返回的结果，如果是 没有发现命令。直接报错，安装失败
     slotCheckInstallStatus(tmp);
@@ -1288,41 +1339,28 @@ void DebListModel::slotConfigReadOutput()
     tmp.remove(QChar('"'), Qt::CaseInsensitive);
     tmp.remove(QChar('\n'), Qt::CaseInsensitive);
 
-    if (tmp.contains("StartInstallAptConfig")) {                                        //获取到当前正在安装配置
-        emit signalStartInstall();
-        refreshOperatingPackageStatus(Operating);                                       //刷新当前的操作状态
-        configWindow->show();                                        //显示配置窗口
-        QString startFlagStr = "StartInstallAptConfig";
-        int num = tmp.indexOf(startFlagStr) + startFlagStr.size();
-        int iCutoutNum = tmp.size() - num;
-        if (iCutoutNum > 0)
-            configWindow->appendTextEdit(tmp.mid(num, iCutoutNum));  //显示配置信息
-        return;
-    }
+    //获取到当前正在安装配置
+    emit signalStartInstall();
+    refreshOperatingPackageStatus(Operating);                                       //刷新当前的操作状态
+    configWindow->show();                                        //显示配置窗口
 
-    QString appendInfoStr = tmp;
-    appendInfoStr.remove(QChar('\"'), Qt::CaseInsensitive);
-    appendInfoStr.remove(QChar('"'), Qt::CaseInsensitive);
-    appendInfoStr.replace("\\n", "\n");
-    appendInfoStr.replace("\n\n", "\n");
-    emit signalAppendOutputInfo(appendInfoStr);                                               //将信息同步显示到安装信息中
-    if (tmp.contains("Not authorized")) {
-        configWindow->close();                                       //没有授权，关闭配置窗口
-    } else {
-        configWindow->appendTextEdit(tmp);                           //授权成功，继续配置
+    int iCutoutNum = tmp.size();
+    if (iCutoutNum > 0) {
+        emit signalAppendOutputInfo(tmp);   // 原本安装信息界面信息也要添加，以备安装完成后查看安装信息
+        configWindow->appendTextEdit(tmp);  // 配置包安装信息界面显示配置信息
     }
 }
 
 void DebListModel::slotConfigInputWrite(QString str)
 {
-    m_procInstallConfig->write(str.toUtf8());                                          //将用户输入的配置项写入到配置安装进程中。
-    m_procInstallConfig->write("\n");                                                  //写入换行，配置生效
+    m_procInstallConfig->pty()->write(str.toUtf8());                                          //将用户输入的配置项写入到配置安装进程中。
+    m_procInstallConfig->pty()->write("\n");                                                  //写入换行，配置生效
 }
 
 void DebListModel::slotCheckInstallStatus(QString installInfo)
 {
     // 判断当前的信息是否是错误提示信息
-    if (installInfo.contains("Cannot run program deepin-deb-installer-dependsInstall: No such file or directory")) {
+    if (installInfo.contains("Error executing command as another user: Request dismissed")) {
         emit signalAppendOutputInfo(installInfo);                                 //输出安装错误的原因
         m_workerStatus = WorkerFinished;                            //刷新包安装器的工作状态
 
