@@ -26,6 +26,7 @@
 #include <QTextLayout>
 #include <QTimer>
 #include <QVBoxLayout>
+#include <QFontMetrics>
 
 #include <QApt/DebFile>
 #include <QApt/Transaction>
@@ -205,7 +206,7 @@ void SingleInstallPage::initPkgInfoView(int fontinfosize)
     QVBoxLayout *pkgNameValueLayout = new QVBoxLayout();        //实际获取到包名
     pkgNameValueLayout->setSpacing(0);                              //设置控件间距
     pkgNameValueLayout->setContentsMargins(0, 0, 0, 0);
-    pkgNameValueLayout->addSpacing(4 + 4);                          //增加空间
+    pkgNameValueLayout->addSpacing(4); //增加空间
     pkgNameValueLayout->addWidget(m_packageName);                   //添加控件
 
     QHBoxLayout *pkgNameLayout = new QHBoxLayout();             //包名的控件布局
@@ -258,8 +259,8 @@ void SingleInstallPage::initPkgInfoView(int fontinfosize)
     QString normalFontFamily = Utils::loadFontFamilyByType(Utils::SourceHanSansNormal);
     QString mediumFontFamily = Utils::loadFontFamilyByType(Utils::SourceHanSansMedium);
 
-    Utils::bindFontBySizeAndWeight(packageVersion, mediumFontFamily, 14, QFont::Medium);        //设置版本提示label的字体大小和样式
-    Utils::bindFontBySizeAndWeight(packageName, mediumFontFamily, 14, QFont::Medium);           //设置包名提示Label的字体大小和样式
+    Utils::bindFontBySizeAndWeight(packageVersion, mediumFontFamily, 14, QFont::DemiBold);        //设置版本提示label的字体大小和样式
+    Utils::bindFontBySizeAndWeight(packageName, mediumFontFamily, 14, QFont::DemiBold);           //设置包名提示Label的字体大小和样式
     Utils::bindFontBySizeAndWeight(m_packageName, normalFontFamily, 14, QFont::ExtraLight);     //设置实际包名label的字体大小和样式
     Utils::bindFontBySizeAndWeight(m_packageVersion, normalFontFamily, 14, QFont::ExtraLight);  //设置实际版本Label的字体大小和样式
 
@@ -273,24 +274,13 @@ void SingleInstallPage::initPkgInfoView(int fontinfosize)
 void SingleInstallPage::initTabOrder()
 {
     // 调整tab切换焦点的顺序，第一个焦点是infoControlButton中的DCommandLinkButton
-    if(m_installButton->isVisible()){
-        QWidget::setTabOrder(m_infoControlButton->controlButton(), m_installButton);        //当前包首次安装
-    }
+    QWidget::setTabOrder(m_infoControlButton->controlButton(), m_installButton);        //当前包首次安装
+    QWidget::setTabOrder(m_infoControlButton->controlButton(), m_backButton);           //安装完成或安装失败
+    QWidget::setTabOrder(m_backButton, m_doneButton);                                   //安装完成场景
+    QWidget::setTabOrder(m_backButton, m_confirmButton);                                //不能安装场景
 
-    if(m_backButton->isVisible()){
-        QWidget::setTabOrder(m_infoControlButton->controlButton(), m_backButton);           //安装完成或安装失败
-        if(m_doneButton->isVisible()){
-            QWidget::setTabOrder(m_backButton, m_doneButton);                                   //安装完成场景
-        }
-        if(m_confirmButton->isVisible()){
-            QWidget::setTabOrder(m_backButton, m_confirmButton);                                //不能安装场景
-        }
-    }
-
-    if(m_uninstallButton->isVisible()){
-        QWidget::setTabOrder(m_infoControlButton->controlButton(), m_uninstallButton);      //当前场景为重新安装
-        QWidget::setTabOrder(m_uninstallButton, m_reinstallButton);                         //重新安装场景
-    }
+    QWidget::setTabOrder(m_infoControlButton->controlButton(), m_uninstallButton);      //当前场景为重新安装
+    QWidget::setTabOrder(m_uninstallButton, m_reinstallButton);                         //重新安装场景
 }
 
 void SingleInstallPage::initButtonFocusPolicy()
@@ -711,9 +701,13 @@ void SingleInstallPage::slotWorkerFinished()
         m_confirmButton->setVisible(true);
         m_tipsLabel->setCustomDPalette(DPalette::TextWarning);
 
-        if (m_operate == Install || m_operate == Reinstall)
-            m_tipsLabel->setText(index.data(DebListModel::PackageFailReasonRole).toString());   //添加安装失败原因的提示
-        else {
+        if (m_operate == Install || m_operate == Reinstall){
+            //添加安装失败原因的提示
+            QFont font;
+            QFontMetrics elideFont(font);
+            m_tipsLabel->setText(elideFont.elidedText(index.data(DebListModel::PackageFailReasonRole).toString(), Qt::ElideRight, m_tipsLabel->width()-100));//修复授权取消后无提示的问题
+            m_tipsLabel->setToolTip(index.data(DebListModel::PackageFailReasonRole).toString());
+        } else {
             m_tipsLabel->setText(tr("Uninstall Failed"));                                       //卸载只显示卸载失败
         }
     } else {
@@ -918,7 +912,6 @@ void SingleInstallPage::setAuthBefore()
             || dependsStat == DebListModel::ArchBreak   //添加架构不匹配的处理
 //            || dependsStat == DebListModel::Prohibit    //添加应用黑名单处理
         ) {
-        m_tipsLabel->setText(index.data(DebListModel::PackageFailReasonRole).toString());//修复授权取消后无提示的问题
         m_tipsLabel->setCustomDPalette(DPalette::TextWarning);
         m_confirmButton->setVisible(true);
         m_backButton->setVisible(true);
